import { useState, useRef, useCallback } from 'react';

var queryParams = function queryParams(key, region, // https://developers.google.com/maps/coverage
language, // https://developers.google.com/maps/faq#languagesupport
libraries) {
  var queryObject = {
    key: key,
    w: 'weekly',
    region: region,
    language: language,
    libraries: libraries.sort().join(',')
  };
  return new URLSearchParams(queryObject).toString();
};
var removeAllGmapAPIScript = function removeAllGmapAPIScript() {
  document.querySelectorAll('script[src^="https://maps.googleapis.com"]').forEach(function (script) {
    return script.remove();
  });
};
var getAllGmapAPIScriptLength = function getAllGmapAPIScriptLength() {
  return document.querySelectorAll('script[src^="https://maps.googleapis.com"]').length;
};
var useScriptLoader = function useScriptLoader(_ref) {
  var apiKey = _ref.apiKey,
      libraries = _ref.libraries;

  var _useState = useState(false),
      isMapReady = _useState[0],
      setIsMapReady = _useState[1];

  var _useState2 = useState(false),
      isReloadOk = _useState2[0],
      setIsReloadOk = _useState2[1];

  var isProcessing = useRef(false);
  var google = window.google;
  var checkAllGmapAPIScripts = useCallback(function (retry, interval, length) {
    if (retry === void 0) {
      retry = 0;
    }

    if (interval === void 0) {
      interval = 1000;
    }

    if (length === void 0) {
      length = 0;
    }

    var retries = retry;
    var scriptsLength = length;
    var retryInterval = setInterval(function () {
      if (scriptsLength > 1 || retries === 7) {
        clearInterval(retryInterval);
        setIsReloadOk(scriptsLength > 1);
        setTimeout(function () {
          return isProcessing.current = false;
        }, 0);
      }

      scriptsLength = getAllGmapAPIScriptLength();
      retries += 1;
    }, interval);
  }, []);
  var deleteGmapsInstance = useCallback(function (google) {
    delete google.maps;
  }, []);
  var loadScript = useCallback(function (language, region) {
    if (isProcessing.current) return false;
    removeAllGmapAPIScript();
    setIsMapReady(false);
    setIsReloadOk(false);
    isProcessing.current = true;

    if (google !== undefined) {
      deleteGmapsInstance(google);
    }

    var script = document.createElement('script');
    Object.assign(script, {
      id: 'googlemaps',
      type: 'text/javascript',
      defer: true,
      async: true,
      src: "https://maps.googleapis.com/maps/api/js?" + queryParams(apiKey, region, language, libraries),
      onload: function onload() {
        return setIsMapReady(true);
      }
    });
    document.head.appendChild(script);
    checkAllGmapAPIScripts();
    return true;
  }, [apiKey, checkAllGmapAPIScripts, google, libraries, deleteGmapsInstance]);
  return {
    loadScript: loadScript,
    isMapReady: isMapReady,
    isReloadOk: isReloadOk,
    checkAllGmapAPIScripts: checkAllGmapAPIScripts
  };
};

export { getAllGmapAPIScriptLength, queryParams, removeAllGmapAPIScript, useScriptLoader };
//# sourceMappingURL=gmaps-script-loader.esm.js.map
